package de.intevation.mxd.reader;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.SimpleMarkerSymbol;
import com.esri.arcgis.display.esriSimpleMarkerStyle;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;

/**
 * Reads simple marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class SimpleMarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(SimpleMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private SimpleMarkerSymbol symbol;

    public SimpleMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof SimpleMarkerSymbol) {
            this.symbol = (SimpleMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a SimpleMarkerSymbol!");
        }
    }

    public SimpleMarkerSymbolReader(IMarkerSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof SimpleMarkerSymbol) {
            this.symbol = (SimpleMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a SimpleMarkerSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        symbolElement.setAttribute("name", symbol.getNameString());
        if(symbol.getStyle() == esriSimpleMarkerStyle.esriSMSCircle)
            symbolElement.setAttribute("style", "point");

        if(symbol.getColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getColor();
            Color c = new Color (
                color.getRed(),
                color.getGreen(),
                color.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
            symbolElement.setAttribute("transparency",
                String.valueOf(color.getTransparency()));
        }
        else {
            RgbColor col = new RgbColor();
            col.setRGB(symbol.getColor().getRGB());
            Color c = new Color (
                col.getRed(),
                col.getGreen(),
                col.getBlue());
            symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
            symbolElement.setAttribute("transparency",
                String.valueOf(col.getTransparency()));
        }

        symbolElement.setAttribute("size", String.valueOf(symbol.getSize()));
        symbolElement.setAttribute("outline_size",
            String.valueOf(symbol.getOutlineSize()));
        if(symbol.getOutlineColor() instanceof IRgbColor) {
            IRgbColor color = (IRgbColor)symbol.getOutlineColor();
            Color c = new Color (
                color.getRed(),
                color.getGreen(),
                color.getBlue());
            symbolElement.setAttribute(
                    "outline_color",
                    String.valueOf(c.getRGB()));
            symbolElement.setAttribute("outline_transparency",
                String.valueOf(color.getTransparency()));
        }
        else {
            RgbColor col = new RgbColor();
            col.setRGB(symbol.getOutlineColor().getRGB());
            Color c = new Color (
                col.getRed(),
                col.getGreen(),
                col.getBlue());
            symbolElement.setAttribute(
                "outline_color",
                String.valueOf(c.getRGB()));
            symbolElement.setAttribute("outline_transparency",
                String.valueOf(col.getTransparency()));
        }

        symbolElement.setAttribute("angle", String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute("offset",
            symbol.getXOffset() + "," + symbol.getYOffset());
        symbolElement.setAttribute("type", "marker");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
